"""
This module contains functions to download json data from the web
"""
import requests


def get_json(url):
    """
    get_json(url)
    url: url of the json data to download
    returns: json data dictionary
    """
    response = requests.get(url, timeout=5)
    if response.status_code == 200:
        data = response.json()
        return data

    return False


# print(get_json("https://jsonplaceholder.typicode.com/todos/1"))



from setuptools import find_packages, setup

__version__ = "0.3.1"

setup(
    name="web_utils_software",
    version=__version__,
    description="Python Project package",
    long_description="Project to set web utils to get data from the web",
    author="Wilson Ramirez",
    author_email="wil_ramirez02@hotmail.com",
    license="MIT",
    package_dir={"": "src"},
    packages=find_packages(where="src"),
    # install_requires=["numpy", "pandas"],
    # entry_points={
    #     "console_scripts": [
    #         "get-data=src.json_utils:get_json",
    #         "get-image=src.image_utils:get_image",
    #     ]
    # },
)



"""
This module contains functions to download images from the web
"""
import shutil

import requests


def get_image(url, filename):
    # document this function with a docstring
    """
    get_image(url, filename)
    url: url of the image to download
    filename: name of the file to save the image to
    returns: Boolean
    """
    response = requests.get(url, stream=True, timeout=5)
    if response.status_code == 200:
        response.raw.decode_content = True
        # context managers Corey Schafer
        with open(filename, "wb") as file:
            shutil.copyfileobj(response.raw, file)
            print("Image successfully Downloaded: ", filename)
        return True

    print("Image couldn't be retrieved")
    return False


# get_image(
#     "https://th.bing.com/th/id/R.fcd349af80cb44e5a32bc3696019cf5f?rik=8bH1xMwmkghXvg&pid=ImgRaw&r=0",
#     "test.jpg",
# )
